@@ -1,4 +1,7 @@
+from cgi import parse_qs
+from urllib import urlencode
 from urllib2 import HTTPError, URLError
+from urlparse import urlsplit, urlunsplit
 
 from django.conf import settings
 from django.utils.functional import update_wrapper
@@ -45,3 +48,9 @@ def fail_whale(f):
                     raise
         return f(*args, **kwargs)
     return update_wrapper(wrapper, f)
+
+def update_qs(url, dictionary):
+    s, n, p, query, f = urlsplit(str(url))
+    query_dict = parse_qs(query)
+    query_dict.update(dictionary)
+    return urlunsplit((s, n, p, urlencode(query_dict), f))
